==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_oc_prv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acuelh dau sit',
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Leis articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'I a ges d\'article a aquela adrei&ccedil;a ',
'aucun_auteur' => 'I a ges d\'autor a aquela adrei&ccedil;a ',
'aucun_site' => 'I a ges de sit a aquela adrei&ccedil;a ',
'aucune_breve' => 'I a ges de br&egrave;va a aquela adrei&ccedil;a ',
'aucune_rubrique' => 'I a ges de rubrica a aquela adrei&ccedil;a ',
'autres_breves' => 'Autrei br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autrei grops de mots claus',
'autres_sites' => 'Autrei sits',

// B
'bonjour' => 'Bonjorn',
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueu sit',

// D
'date' => 'Data',
'dernier_ajout' => 'Darrier apondon',
'dernieres_breves' => 'Darrierei br&egrave;vas',
'derniers_articles' => 'Darriers articles',
'derniers_commentaires' => 'Darriers comentaris',
'derniers_messages_forum' => 'Darriers messatges publicats dins lei forums',

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En resp&ograve;nsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// M
'meme_auteur' => 'Dau meteis autor',
'meme_rubrique' => 'Dins la meteissa rubrica',
'memes_auteurs' => 'Dei meteis autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Lei messatges de forums mai recents',
'mots_clefs' => 'Mots claus',
'mots_clefs_meme_groupe' => 'Mots claus dins lo meteis grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Lei novetats',
'nouveautes_web' => 'Novetats subre lo web',
'nouveaux_articles' => 'Articles n&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas n&ograve;vas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Pod&egrave;tz participar a la vida d\'aqueu sit e prepausar leis articles v&ograve;stres en vos inscrivent &ccedil;ai sota. Recebretz sus lo c&ograve;p un e-mail que vos indicar&agrave; v&ograve;strei c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepausar un sit d\'apondre a aquesta rubrica:',

// R
'repondre_article' => 'Resp&ograve;ndre a aquel article',
'repondre_breve' => 'Resp&ograve;ndre a aquela br&egrave;va',
'repondre_message' => 'Resp&ograve;ndre a aqueu messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament dei forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat amb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'suite' => 'seguida',
'sur_web' => 'Subre lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vaic&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa leis articles e br&egrave;vas publicats dempuei',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vejatz en linha',
'voir_squelette' => 'telecargar l\'esqueleta d\'aquela pagina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_oc_prv.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Acuelh dau sit',
'article' => 'Article', # NEW
'articles' => 'Articles',
'articles_auteur' => 'Articles d\'aquel autor',
'articles_populaires' => 'Leis articles mai populars',
'articles_rubrique' => 'Articles d\'aquela rubrica',
'aucun_article' => 'I a ges d\'article a aquela adrei&ccedil;a ',
'aucun_auteur' => 'I a ges d\'autor a aquela adrei&ccedil;a ',
'aucun_site' => 'I a ges de sit a aquela adrei&ccedil;a ',
'aucune_breve' => 'I a ges de br&egrave;va a aquela adrei&ccedil;a ',
'aucune_rubrique' => 'I a ges de rubrica a aquela adrei&ccedil;a ',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => 'Autrei br&egrave;vas',
'autres_groupes_mots_clefs' => 'Autrei grops de mots claus',
'autres_sites' => 'Autrei sits',

// B
'bonjour' => 'Bonjorn',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Br&egrave;vas',

// C
'commenter_site' => 'Comentar aqueu sit',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => 'Data',
'dernier_ajout' => 'Darrier apondon',
'dernieres_breves' => 'Darrierei br&egrave;vas',
'derniers_articles' => 'Darriers articles',
'derniers_commentaires' => 'Darriers comentaris',
'derniers_messages_forum' => 'Darriers messatges publicats dins lei forums',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => 'Edicion en m&ograve;de t&egrave;xt de',
'en_reponse' => 'En resp&ograve;nsa a:',
'en_resume' => 'En resumit',
'envoyer_message' => 'Mandar un messatge',
'espace_prive' => 'Espaci privat',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => 'Forum',

// H
'hierarchie_site' => 'Ierarquia dau sit',

// J
'jours' => 'jorns',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => 'Dau meteis autor',
'meme_rubrique' => 'Dins la meteissa rubrica',
'memes_auteurs' => 'Dei meteis autors',
'message' => 'Messatge',
'messages_forum' => 'Messatges de forum',
'messages_recents' => 'Lei messatges de forums mai recents',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Mots claus',
'mots_clefs_meme_groupe' => 'Mots claus dins lo meteis grop',

// N
'navigation' => 'Navigacion',
'nom' => 'Nom',
'nouveautes' => 'Lei novetats',
'nouveautes_web' => 'Novetats subre lo web',
'nouveaux_articles' => 'Articles n&ograve;us',
'nouvelles_breves' => 'Br&egrave;vas n&ograve;vas',

// P
'page_precedente' => 'pagina precedenta',
'page_suivante' => 'pagina seguenta',
'par_auteur' => 'per&nbsp;',
'participer_site' => 'Pod&egrave;tz participar a la vida d\'aqueu sit e prepausar leis articles v&ograve;stres en vos inscrivent &ccedil;ai sota. Recebretz sus lo c&ograve;p un e-mail que vos indicar&agrave; v&ograve;strei c&ograve;des per accedir a l\'espaci privat dau sit.',
'plan_site' => 'Plan dau sit',
'popularite' => 'Popularitat',
'poster_message' => 'Postar un messatge',
'proposer_site' => 'Pod&egrave;tz prepausar un sit d\'apondre a aquesta rubrica:',

// R
'repondre_article' => 'Resp&ograve;ndre a aquel article',
'repondre_breve' => 'Resp&ograve;ndre a aquela br&egrave;va',
'repondre_message' => 'Resp&ograve;ndre a aqueu messatge',
'resultats_recherche' => 'Resultats de la c&egrave;rca',
'retour_debut_forums' => 'Retorn au comen&ccedil;ament dei forums',
'rubrique' => 'Rubrica',
'rubriques' => 'Rubricas',

// S
'signatures_petition' => 'Signaturas',
'site_realise_avec_spip' => 'Sit realizat amb SPIP',
'sites_web' => 'Sits web',
'sous_rubriques' => 'Sosrubricas',
'spam' => 'Spam', # NEW
'suite' => 'seguida',
'sur_web' => 'Subre lo web',
'syndiquer_rubrique' => 'Sindicar aquela rubrica',
'syndiquer_site' => 'Sindicar tot lo sit',

// T
'texte_lettre_information' => 'Vaic&iacute; la letra d\'informacion dau sit',
'texte_lettre_information_2' => 'Aquela letra recensa leis articles e br&egrave;vas publicats dempuei',

// V
'ver_imprimer' => 'Version d\'estampar',
'voir_en_ligne' => 'Vejatz en linha',
'voir_squelette' => 'telecargar l\'esqueleta d\'aquela pagina'
);

?>
